Avoid busy loop on rsync exit status 12 or 13.
[dss.git] / snap.h
diff --git a/snap.h b/snap.h
index 1e9fc2b87423ae520ef6f3b6a2b2d7e3d0b52e89..5c2f20b2885e19919afabff1369908fdb6c5bf18 100644 (file)
--- a/snap.h
+++ b/snap.h
@@ -1,23 +1,37 @@
-enum {
+/*
+ * Copyright (C) 2008-2009 Andre Noll <maan@systemlinux.org>
+ *
+ * Licensed under the GPL v2. For licencing details see COPYING.
+ */
+
+/** The possible states for snapshot creation/removal. */
+enum hook_status {
        /** We are ready to take the next snapshot. */
-       SCS_READY,
-       /** The pre-creation hook has been started. */
-       SCS_PRE_HOOK_RUNNING,
-       /** The pre-creation hook exited successfully. */
-       SCS_PRE_HOOK_SUCCESS,
-       /** The rsync process is running. */
-       SCS_RSYNC_RUNNING,
-       /** The rsync process exited successfully. */
-       SCS_RSYNC_SUCCESS,
-       /** The post-create hook has been started- */
-       SCS_POST_HOOK_RUNNING,
+       HS_READY,
+       /** The pre-create/pre-remove hook has been started. */
+       HS_PRE_RUNNING,
+       /** The pre-create/pre-remove hook exited successfully. */
+       HS_PRE_SUCCESS,
+       /** The rsync/rm process is running. */
+       HS_RUNNING,
+       /** The rsync/rm process exited successfully. */
+       HS_SUCCESS,
+       /** The rsync/rm process needs to be restarted. */
+       HS_NEEDS_RESTART,
+       /** The post-create/post-remove hook has been started. */
+       HS_POST_RUNNING,
 };
 
/*
* complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43
* complete, being deleted: 1204565370-1204565371.being_deleted
* incomplete, not being deleted: 1204565370-incomplete
* incomplete, being deleted: 1204565370-incomplete.being_deleted
  */
 enum snapshot_status_flags {
        /** The rsync process terminated successfully. */
@@ -26,11 +40,20 @@ enum snapshot_status_flags {
        SS_BEING_DELETED = 2,
 };
 
+/** Describes one snapshot. */
 struct snapshot {
+       /** The name of the directory, relative to the destination dir. */
        char *name;
+       /** Seconds after the epoch when this snapshot was created. */
        int64_t creation_time;
+       /**
+        * Seconds after the epoch when creation of this snapshot completed.
+        * Only meaningful if the SS_COMPLETE bit is set.
+        */
        int64_t completion_time;
+       /** See \ref snapshot_status_flags. */
        enum snapshot_status_flags flags;
+       /** The interval this snapshot belongs to. */
        unsigned interval;
 };
 
@@ -48,9 +71,11 @@ struct snapshot_list {
        unsigned *interval_count;
 };
 
+/** Iterate over all snapshots in a snapshot list. */
 #define FOR_EACH_SNAPSHOT(s, i, sl) \
        for ((i) = 0; (i) < (sl)->num_snapshots && ((s) = (sl)->snapshots[(i)]); (i)++)
 
+/** Iterate backwards over all snapshots in a snapshot list. */
 #define FOR_EACH_SNAPSHOT_REVERSE(s, i, sl) \
        for ((i) = (sl)->num_snapshots; (i) > 0 && ((s) = (sl)->snapshots[(i - 1)]); (i)--)
 
@@ -64,9 +89,12 @@ __malloc char *being_deleted_name(struct snapshot *s);
 int complete_name(int64_t start, int64_t end, char **result);
 __malloc char *name_of_newest_complete_snapshot(struct snapshot_list *sl);
 
-static inline struct snapshot *get_oldest_snapshot(struct snapshot_list *sl)
+/**
+ * Get the newest snapshot in a snapshot list.
+ */
+_static_inline_ struct snapshot *get_newest_snapshot(struct snapshot_list *sl)
 {
        if (!sl->num_snapshots)
                return NULL;
-       return sl->snapshots[0];
+       return sl->snapshots[sl->num_snapshots - 1];
 }
@@ -1,23 +1,37 @@
 };
 
-/*
- * complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43
- * complete, being deleted: 1204565370-1204565371.being_deleted
- * incomplete, not being deleted: 1204565370-incomplete
- * incomplete, being deleted: 1204565370-incomplete.being_deleted
+/**
+ * The status of a snapshot.
+ *
+ * The snapshot directories come in four different flavours, depending
+ * on how the two status flags are set. Examples:
+ *
+ * Complete, not being deleted: 1204565370-1204565371.Sun_Mar_02_2008_14_33-Sun_Mar_02_2008_14_43.
+ * Complete, being deleted: 1204565370-1204565371.being_deleted.
+ * Incomplete, not being deleted: 1204565370-incomplete.
+ * incomplete, being deleted: 1204565370-incomplete.being_deleted.
  */
 enum snapshot_status_flags {